% % Supplementary material for the paper C.Culmone, P.W.J. Henselmans,
% R.I.B.van Starkenburg, P.Breedveld (2020). Exploring Non-Assembly 3D
% Printing for Novel Compliant Surgical Devices. PLOS ONE. Tested in
% MATLAB 2020a

%% Data for the line plot

clear all, close all, clc

M_Straight=load('mean_straight');
M_S_curve=load('mean_S_curve');
M_D_curve=load('mean_D_curve');

std_Straight=load('std_straight');
std_S_curve=load('std_S_curve');
std_D_curve=load('std_D_curve');

M_St=cell2mat(struct2cell(M_Straight));
M_St=M_St.*-1;
M_S=cell2mat(struct2cell(M_S_curve));
M_D=cell2mat(struct2cell(M_D_curve));
M_D=M_D.*-1;

STD_St=cell2mat(struct2cell(std_Straight));
STD_S=cell2mat(struct2cell(std_S_curve));
STD_D=cell2mat(struct2cell(std_D_curve));

data=[M_St;M_S(1,:); M_D(1,:)];
datastd=[STD_St;STD_S(1,:); STD_D(1,:)];

spread = 0.1;
list = [1-spread 2-spread 3-spread; 1 2 3; 1+spread 2+spread 3+spread];

%% Peak force line plot with error bars for the lateral pose

figure()

y = {'m','g','k'};

    for i = 1:3
    e=errorbar(list(i,:),data(i,:),datastd(i,:),'.');
    e.Color = y{i};
    e.LineWidth = 1;
    e.MarkerSize = 10;
    hold on
    end
    
grid on 
ylabel('Force (N)');
xlabel('Prototype number')
set(gca,'xtick',linspace(0,4,5))
xlim([0,4])
ylim([0,0.5])
title('Lateral')
legend({'Magenta = Straight' 'Green = Single' 'Black = Double'}, 'Location','southeast')