% % Supplementary material for the paper C.Culmone, P.W.J. Henselmans,
% R.I.B.van Starkenburg, P.Breedveld (2020). Exploring Non-Assembly 3D
% Printing for Novel Compliant Surgical Devices. PLOS ONE. Tested in
% MATLAB 2020a

% We analyzed the data mesured from the moment the load cell touches the
% prototype handle to the moment the deflection of the tip was 3 mm

%% Data for Actuation force
clc, clear all, close all

load ('AllData_Handle');


%% Clalculate the max

for j = 1:length(AllData_Handle) 
    AllData_Handle(j).MaxF = max((AllData_Handle(j).Force).*-1);
end

j=1;
sample = {'1' '2' '3'};
for h = 1:length(sample)
    for i = 1:length(AllData_Handle)
        if strcmp(char(AllData_Handle(i).Sample),sample{h}) 
            MaxF(j) = (AllData_Handle(i).MaxF);
            
            j=j+1;
        end
    end
end

%% Calculate mean and standard deviation of the peak force

selection = reshape(MaxF, 30, 3);  %reorganize data
Dev_1_MaxF = selection(:,1);
Dev_2_MaxF = selection(:,2);
Dev_3_MaxF = selection(:,3);

data(:,1)=mean(reshape(Dev_1_MaxF,10,3)); 
data(:,2)= mean(reshape(Dev_2_MaxF,10,3));
data(:,3)= mean(reshape(Dev_3_MaxF,10,3));


datastd(:,1)=std(reshape(Dev_1_MaxF,10,3));
datastd(:,2)= std(reshape(Dev_2_MaxF,10,3));
datastd(:,3)= std(reshape(Dev_3_MaxF,10,3));

devs =datastd(:);
spread = 0.1;
list = [1-spread 2-spread 3-spread; 1 2 3; 1+spread 2+spread 3+spread];

%%  Peak force line plot with error bars

figure()

y = {'g','b','red'};

    for i = 1:3
    e=errorbar(list(i,:),data(i,:),datastd(i,:),'.');
    e.Color = y{i};
    e.LineWidth = 1;
    e.MarkerSize = 10;
    hold on
    end
    
grid on 
ylabel('Force (N)');
xlabel('Prototype number')
set(gca,'xtick',linspace(0,4,5))
xlim([0,4])
ylim([0,2.8])
title('Handle Peak Forces at 3mm')
legend({'green = no load' 'blue = 6g' 'red = 18g'}, 'Location','southeast')
hold off