% % Supplementary material for the paper C.Culmone, P.W.J. Henselmans,
% R.I.B.van Starkenburg, P.Breedveld (2020). Exploring Non-Assembly 3D
% Printing for Novel Compliant Surgical Devices. PLOS ONE. Tested in
% MATLAB 2020a

% We analyzed the data mesured from the moment the load cell touches the
% prototype tip to the moment the deflection of the tip was 9 mm

clc, clear all, close all

%% Data for the single curve pose

load ('AllData_Single');

%% Calculate the max 
for j = 1:length(AllData_Single) 
    AllData_Single(j).MaxF = max((AllData_Single(j).Force).*-1);
end

j=1;
sample = {'1' '2' '3'};
for h = 1:length(sample)
    for i = 1:length(AllData_Single)
        if strcmp(char(AllData_Single(i).Sample),sample{h}) 
            MaxF(j) = (AllData_Single(i).MaxF);
            
            j=j+1;
        end
    end
end

%% Calculate mean and standard deviation of the peak force

selection = reshape(MaxF, 20, 3);
Dev_1_MaxF = selection(:,1);
Dev_2_MaxF = selection(:,2);
Dev_3_MaxF = selection(:,3);

data(:,1)=mean(reshape(Dev_1_MaxF,10,2)); 
data(:,2)= mean(reshape(Dev_2_MaxF,10,2));
data(:,3)= mean(reshape(Dev_3_MaxF,10,2));

datastd(:,1)=std(reshape(Dev_1_MaxF,10,2));
datastd(:,2)= std(reshape(Dev_2_MaxF,10,2));
datastd(:,3)= std(reshape(Dev_3_MaxF,10,2));

devs =datastd(:);
spread = 0.1;
list = [1-spread 2-spread 3-spread; 1 2 3];


%% Peak force line plot with error bars for the vertical pose

figure()
    for i = 1:3
    e=errorbar(list(1,i),data(1,i),datastd(1,i),'.');
    e.Color = 'k';
    e.LineWidth = 1;
    e.MarkerSize = 10;
    hold on
    end
    
grid on 
ylabel('Force (N)');
xlabel('Prototype number')
set(gca,'xtick',linspace(0,4,5))
xlim([0,4]) 
ylim([0,0.5])
title('Single curve (Vertical)')
hold off

%% Peak force line plot with error bars for the axial pose

figure()
    for i = 1:3
    e=errorbar(list(2,i),data(2,i),datastd(2,i),'.');
    e.Color = 'k';
    e.LineWidth = 1;
    e.MarkerSize = 10;
    hold on
    end
    
grid on 
ylabel('Force (N)');
xlabel('Prototype number')
set(gca,'xtick',linspace(0,4,5))
xlim([0,4]) 
ylim([0,0.9])
title('Single curve (axial)')
hold off

%% Select one of the prototype and analyze the data

Device = '1'; %%change this with 1 or 3 in case you want to visualize data of the other devcices
j=1;

for i = 1:length(AllData_Single)
    if strcmp(char(AllData_Single(i).Sample),Device) % strcmp(char(AllData(i).Substrate),substrate)
                
        UsedData(j).Name = AllData_Single(i).Name;
        UsedData(j).Space = AllData_Single(i).Space;
        UsedData(j).Force = (AllData_Single(i).Force).*-1;
        UsedData(j).FMax = max((AllData_Single(i).Force).*-1);
        hold on
       
        j=j+1; 
    end
end

%% Force Displacement plot with average

for i= 1:length(UsedData)
    Length(i)= length(UsedData(i).Force);
end
maxL= max(Length);
minL= min (Length);
index= find(Length==minL);

M=zeros(maxL,10)+(UsedData(index).Space(end)-UsedData(index).Space(1));
N=zeros(maxL,10)+(UsedData(index).Force(end));


figure() 
for i = 1:10
    for j=1:length (UsedData(i).Space) % insert UsedData(i+10) instead of UsedData(i)
    M(j,i)= UsedData(i).Space(j)-UsedData(i).Space(1);
    N(j,i)= (UsedData(i).Force(j));
    end
    plot(M(:,i),(N(:,i)),'k');
    hold on
end

%% Calculate the average

AVEREGE_space=mean(M'); 
AVEREGE_force=mean(N');
plot(AVEREGE_space,AVEREGE_force,'red')
yline(0);
xlabel('Displacement (mm)'), ylabel('Force (N)'), title('Force-Displacement');
grid on
hold off